{% extends "base.html" %}

{% block main %}

<div class="row">
  <div class="col-md-8 col-xs-12 col-md-offset-2 login-form">

    <h2 style="line-height: 23px;">{{ _("Please choose a new password") }}</h2>

    <p>
      Votre mot de passe doit contenir au moins 8 caractères, dont au moins une majuscule,
      une minuscule, et un chiffre.
    </p>

    <form method="POST" name="change_password" role="form">
      {{ csrf.field() }}
      <div class="form-group">
        <input type="password" name="password" placeholder="{{ _("Password") }}"
               autofocus="autofocus" class="form-control" />
      </div>
      <div class="form-group">
        <button class="btn btn-primary" type="submit">{{ _("Change password") }}</button>
        <button class="btn btn-default" type="submit" name="action" value="cancel">{{ _("Cancel") }}</button>
      </div>
    </form>
  </div>
</div>

{% endblock %}
