CKEDITOR.plugins.setLang('bootstrapVisibility', 'en', {
	respTabLabel: 'Responsive Visibility',
	classDetailsHtml: 'For an explanation of what the CSS classes listed above are check out Bootstrap 3\'s documentation at:<br> <a href="http://getbootstrap.com/css/#responsive-utilities" target="_blank">http://getbootstrap.com/css/#responsive-utilities</a>',
	none: 'None',
	hidden_xs: 'hidden-xs',
	hidden_sm: 'hidden-sm',
	hidden_md: 'hidden-md',
	hidden_lg: 'hidden-lg',
	visible_xs_block: 'visible-xs-block',
	visible_sm_block: 'visible-sm-block',
	visible_md_block: 'visible-md-block',
	visible_lg_block: 'visible-lg-block',
	visible_xs_inline_block: 'visible-xs-inline-block',
	visible_sm_inline_block: 'visible-sm-inline-block',
	visible_md_inline_block: 'visible-md-inline-block',
	visible_lg_inline_block: 'visible-lg-inline-block',
	visible_xs_inline: 'visible-xs-inline',
	visible_sm_inline: 'visible-sm-inline',
	visible_md_inline: 'visible-md-inline',
	visible_lg_inline: 'visible-lg-inline'
});