// Abilian default theme
@import "variables.less";
@import "compat.less";
@import "layout.less";
@import "form.less";
@import "datatables.less";
@import "user.less";
@import "navbar.less";
@import "activities.less";
@import "admin.less";
@import "search.less";
@import "comments.less";
@import "attachments.less";
@import "models.less";

mark {
  background-color: #fff8bb; // boostrap uses state-warning-bg, but it's too light to be seen
}

a mark {
  // in normalize.less there is a rule for changing 'mark' color, but we don't want that in links
  color: inherit;
}

.caret-down {
  // this is bootstrap's standard caret. Synonym is added for markup clarity
  // when using .carret-down/.carret-up together
  .caret();
}

.caret-up {
  .caret();

  border-top: 0;
  border-bottom: @caret-width-base solid;
  content: "";
}

// Flask debugtoolbar
#flDebug #flDebugToolbarHandle {
  // align handle at bottom of navigation bar
  top: @line-height-computed + @navbar-padding-vertical * 2 !important;
}
